@@ -51,6 +51,7 @@ class ModelRepository:
                 output_file = os.path.join(output_dir, model_name + ".py")
                 with open(output_file, "wb") as modelzip:
                     modelzip.write(blob[0])
+                conn.commit()
         except Exception as e:
             return (
                 NoResult,
@@ -116,7 +117,6 @@ class ModelRepository:
                         (ModelRepository.MODEL_REPO_TABLE, model_name, python_script_content))
             conn.commit()
         except Exception as e:
-            conn.rollback()
             return (
                 NoResult,
                 FintixError(exception=e, message="failed to upload converted python to database", exit_code=None,
