@@ -3,7 +3,7 @@ import time
 import logging
 
 from fintix_modelcurator.const import *
-from fintix_modelcurator.repository import *
+from fintix_modelcurator.repository import ModelRepository
 
 
 def get_currenttime_ms():
@@ -29,10 +29,6 @@ def handle_error(error, logger=None):
             os._exit(exit_code)
 
 
-def handle_error(error):
-    handle_error(error, None)
-
-
 def upload_model(model_name):
     res, err = ModelRepository.getInstance().upload_model(model_name)
     if err is None:
